@@ -308,6 +308,7 @@ g.part4 = function(datadir=c(),metadatadir=c(),f0=f0,f1=f1,idloc=1,loglocation =
             # change time stamps to be a continues time
             if (SptOnset < 12) SptOnset = SptOnset + 24 #shift 24 hours to create continues time
             if (SptWake <= 12) SptWake = SptWake + 24 #shift 24 hours to create continues time
+            if (SptWake > 12 & SptWake < 18 & daysleeper[j] == TRUE) SptWake = SptWake + 24 # NEW 10/5/2018 by Vincent
             if (daysleeper[j] == TRUE) {
               logdur[i] = SptOnset - SptWake
             } else {
@@ -343,6 +344,7 @@ g.part4 = function(datadir=c(),metadatadir=c(),f0=f0,f1=f1,idloc=1,loglocation =
           #now generate empty overview for this night / person
           dummyspo = matrix(0,1,5); dummyspo[1,1] = 1
           spo_day = c()
+          # cat(daysleeper[j])s
           #============================================================================================
           for (loaddaysi in 1:loaddays) { #load twice if daysleeper because we also need data from the afternoon on the next day
             # now get accelerometer sleep detection
@@ -397,12 +399,11 @@ g.part4 = function(datadir=c(),metadatadir=c(),f0=f0,f1=f1,idloc=1,loglocation =
                       }
                       tmpCmd = paste("spo_day",k,"= spo",sep="") #spo needs to be rememered specific to definition
                       eval(parse(text = tmpCmd))
-                      
                     } else {
                       tmpCmd = paste("spo_day",k,"= c()",sep="")
                       eval(parse(text = tmpCmd))
                     }
-                  } else if (loaddaysi == 2 & length(spo_day) > 0) { #length check added because day may have been skipped
+                  } else if (loaddaysi == 2 & length(eval(parse(text = paste0("spo_day",k)))) > 0) { #length check added because day may have been skipped
                     w2 = which(spo[,2] < 18) #only use periods starting before 6pm
                     if (length(w2) > 0) {
                       spo = as.matrix(spo[w2,])
@@ -415,6 +416,7 @@ g.part4 = function(datadir=c(),metadatadir=c(),f0=f0,f1=f1,idloc=1,loglocation =
                       spo[,2:3] = spo[,2:3]+ 24 # + 24 to create continues timelines for day 2 relative to day 1
                       tmpCmd = paste("spo_day2",k,"= spo",sep="") #spo needs to be rememered specific to definition
                       eval(parse(text = tmpCmd))
+                      
                     } else {
                       tmpCmd = paste("spo_day2",k,"= c()",sep="")
                       eval(parse(text = tmpCmd))
@@ -502,6 +504,7 @@ g.part4 = function(datadir=c(),metadatadir=c(),f0=f0,f1=f1,idloc=1,loglocation =
                 }
                 #sbefore = spocum.t[,4]
                 delta_t1 = diff(as.numeric(spocum.t[,3]))
+                
                 spocum.t[,4] = correct01010pattern(spocum.t[,4])
                 #----------------------------
                 nightsummary[sumi,1] = accid
@@ -529,13 +532,13 @@ g.part4 = function(datadir=c(),metadatadir=c(),f0=f0,f1=f1,idloc=1,loglocation =
                 nightsummary[sumi,6] = defi #sleep definition
                 #------------------------------------
                 # SLEEP LOG
-                #correct SptOnset and SptWake to fall within [12-36] window and store as sleeplog_onset and sleeplog_wake
+                #correct SptOnset and SptWake to fall within [12-36] window and store as sleeplog_onset and sleeplog_wake, except when it is a daysleeper
                 if (SptOnset > 36) {
                   nightsummary[sumi,7] = SptOnset-24 #onset
                 } else {
                   nightsummary[sumi,7] = SptOnset
                 }
-                if (SptWake > 36) {
+                if (SptWake > 36 & daysleeper[j] == FALSE) {
                   nightsummary[sumi,8] = SptWake-24 #wake
                 } else {
                   nightsummary[sumi,8] = SptWake
