@@ -1,5 +1,5 @@
 g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7,hrs.del.start=0,hrs.del.end =0,
-                   loglocation= c(),excludefirstlast=FALSE,windowsizes=c(5,900,3600), acc.metric="ENMO",
+                   loglocation= c(),excludefirstlast.part5=FALSE,windowsizes=c(5,900,3600), acc.metric="ENMO",
                    boutcriter.mvpa=0.8,boutcriter.in=0.9,boutcriter.lig=0.8,storefolderstructure=FALSE,
                    threshold.lig = c(40),
                    threshold.mod = c(100),
@@ -158,7 +158,7 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
           # SUSTAINED INACTIVITY BOUTS
           Sbackup = S
           S2 = S[which(S$definition==j),] # simplify to one definition
-          detection = rep(0,length(time))
+          sibdetection = rep(0,length(time))
           tmp = S2 #[which(S2$night==h),]
           s0s1 = c()
           pr0 = 1
@@ -199,7 +199,7 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
               }
             }
           }
-          detection[s0s1] = 1
+          sibdetection[s0s1] = 1
           # extract time and from that the indices for midnights
           tempp = unclass(as.POSIXlt(iso8601chartime2POSIX(time,tz=desiredtz),tz=desiredtz))
           if (is.na(tempp$sec[1]) == TRUE) {
@@ -213,17 +213,15 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
           } else {
             nightsi = which(sec == 0 & min == (dayborder-floor(dayborder))*60 & hour == floor(dayborder)) #shift the definition of midnight if required
           }
+          
           # create copy of only relevant part of sleep summary dataframe
           summarysleep_tmp2 = summarysleep_tmp[which(summarysleep_tmp$acc_def == j),]
           # following code was move to here, because otherwise it would repeated remove the last night in the loop          
           #           ignore last night because the following day is potentially not complete e.g. by reduce protocol compliance
-          if (excludefirstlast == FALSE) { #undesirable because it will slowly remove alchanged to TRUE on 20 May 2015
-            summarysleep_tmp2 = summarysleep_tmp2[-nrow(summarysleep_tmp2),]
-          }
           #=========
           # SUSTAINED INACTIVITY BOUTS are normally not assessed for the time between the first midnight and the first noon
           # because it is not used for sleep reports (first night is ignored)
-          # Therefore, expand the SIB detection to include this time segment.
+          # Therefore, expand the SIB sibdetection to include this time segment.
           # Step 1: Identify time window that needs to be processed
           redo1 = nightsi[1] - ((60/ws3)*60)
           if (redo1 < 1) redo1 = 1
@@ -253,13 +251,13 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
               sdl1[1:length(sdl1)] = 0 #periodsposture change
             }
           }
-          # update variable detection
-          detection[redo1:redo2] = sdl1
+          # update variable sibdetection
+          sibdetection[redo1:redo2] = sdl1
           #========================================================
           # DIURNAL BINARY CLASSIFICATION INTO SLEEP OR WAKE PERIOD 
           # Note that the sleep date timestamp corresponds to day before night
           w0 = w1 = rep(0,length(summarysleep_tmp2$calendardate))
-          diur = rep(0,length(time)) #0 if wake, 1 if sleep
+          diur = rep(0,length(time)) #diur is a variable to indicate the diurnal rhythm: 0 if wake/daytime, 1 if sleep/nighttime
           pko = which(summarysleep_tmp2$acc_onset == 0 & summarysleep_tmp2$acc_wake == 0 & summarysleep_tmp2$acc_dur_noc == 0)
           if (length(pko) > 0) {
             summarysleep_tmp2 = summarysleep_tmp2[-pko,]
@@ -308,52 +306,35 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
                 diur[s0:s1] = 1
               }
             }
-            #=========
-            # EXPAND DIUR WITH AT LEAST ONE EPOCH AT END OF SLEEP IN FIRST NIGHT TO MARK MORNING AWAKENING
-            if (length(loglocation) > 0) {
-              LOG = read.csv(loglocation)
-              # id = summarysleep_tmp2$id[1]
-              waket= as.character(LOG[which(LOG$STNO == id),which(names(LOG)=="FGAWK2")])
-              if (length(waket) > 0) {
-                if (waket != ""){
-                  waket2 = as.numeric(unlist(strsplit(waket,":")))
-                  waket3 = waket2[1] * (60*(60/ws3)) + waket2[2] * ((60/ws3)) + round(waket2[3]/5)
-                  waketi = nightsi[1] + waket3
-                } else {
-                  waketi = nightsi[1] + ((60/ws3)*8*60)
-                }
-              } else {
-                waketi = nightsi[1] + ((60/ws3)*8*60)
-              }
+           
+            # Jairo's proposal:
+            # Why don't we start with the first epoch of the measurement and advance till we find the first awakening?
+            # Feel free to remove these previous comments if you finally merge this pull request. 
+            # Below, the code analyses the first hour of measurement, if detection is consistently 0,
+            # then the code assumes that the accelerometer was initialized during the day and do 
+            # not look for a "inexistent" first awakening. Otherwise, the code keep looken for the first awakening.
+            # Response Vincent: ok, good idea, but we need to use the diur variable which represents nighttime/daytime.
+            # detection only represents sustained inctivity bouts. I have now updated the object name to be 
+            # sibdetection to clarify this
+            if (diur[1] != 0 & (60/ws3)*60 < nightsi[1]) { # the statement with unique that was here results is ambiguous because it can have multiple values
+              # waketi = which(diff(detection) == -1)[1]
+              # onseti = which(diff(detection) == 1)[1] # added 20/4/2018 by VvH
+              waketi = which(diff(diur) == -1)[1]
+              onseti = which(diff(diur) == 1)[1] # added 20/4/2018 by VvH
             } else {
-              waketi = nightsi[1] + ((60/ws3)*8*60)
+              waketi = 0
+              onseti = 0 # added 20/4/2018 by VvH
             }
-            # now round off to nearest end of sleep detection
-            found = FALSE
-            step = 0
-            while (found == FALSE) {
-              if (detection[waketi] == 1) {
-                step = step + 1
-              } else {
-                step = step - 1
-              }
-              if (detection[waketi+step] != detection[waketi]) {
-                found = TRUE
-                waketi = waketi+step
-              }
-              if (abs(step) == (60/ws3)*(4*60) | (waketi+step) < nightsi[1]) { # do not shift it by more than 4 hours or before the first midnight
-                found = TRUE
-              }
+            if (waketi > 0 & onseti == 0) {
+              diur[1:waketi] = 1
+            } else if (waketi > 0 & onseti > 0) { # added 20/4/2018 by VvH
+              diur[onseti:waketi] = 1
             }
-            #update diur to include at least end of first night (needed to identify awakening)
-            ss0 = nightsi[1]-10 #index in data minus resolution of window
-            if (ss0 < 1) ss0 = 1 # added on 7/9/2015: if previous line results in negative index then use first index
-            diur[ss0:waketi] = 1
             for (TRLi in threshold.lig) {
               for (TRMi in threshold.mod) {
                 for (TRVi in threshold.vig) {
                   
-                  levels = identify_levels(time,diur,detection,ACC,
+                  levels = identify_levels(time,diur,sibdetection,ACC,
                                            TRLi,TRMi,TRVi,
                                            boutdur.mvpa,boutcriter.mvpa,
                                            boutdur.lig,boutcriter.lig,
@@ -386,23 +367,53 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
                   #-------------------------------
                   # ignore all nights in 'inights' before the first waking up and after the last waking up
                   
-                  FM = which(diff(diur) == -1)
-                  if (length(FM) > 0) {
-                    # ignore first and last midnight because we did not do sleep detection on it
-                    nightsi = nightsi[which(nightsi > FM[1] & nightsi < FM[length(FM)])]
-                  }
+                  FM = which(diff(diur) == -1)                  
+                  nightsi_bu = nightsi
                   # now 0.5+6+0.5 midnights and 7 days
                   for (timewindowi in timewindow) {
-                    for (wi in 1:(nrow(summarysleep_tmp2))) { #loop through 7 windows
+                    nightsi = nightsi_bu 
+                    if (timewindowi == "WW") {
+                      plusrow = 1
+                      if (length(FM) > 0) {
+                        # ignore first and last midnight because we did not do sleep detection on it
+                        nightsi = nightsi[which(nightsi > FM[1] & nightsi < FM[length(FM)])]
+                      }
+                    } else {
+                      plusrow = 1
+                    }
+                    for (wi in 1:(nrow(summarysleep_tmp2)+plusrow)) { #loop through 7 windows (+1 to include the data after last awakening)
                       #check that this is a meaningful day
                       qqq = rep(0,2)
                       # check that it is possible to find both windows in the data for this day
+                      # qqq definitions changed so we get acc_onset and acc_wake regarding to the same day of measurement in the same row. 
+                      # Also, it allows for the analysis of the first day for those studies in which the accelerometer is 
+                      # started during the morning and the first day is of interest.
                       if (timewindowi == "MM") {
-                        qqq[1] = nightsi[wi]+1
-                        qqq[2] = nightsi[wi+1]
-                      } else {
-                        qqq[1] = which(diff(diur) == -1)[wi]+1 #waking time (select based on diurnal marking)
-                        qqq[2] = which(diff(diur) == -1)[wi+1] #wakingtime next day (select based on diurnal marking)
+                        if (wi==1) {
+                          qqq[1] = 1
+                          qqq[2] = nightsi[wi]
+                        } else if (wi<=nrow(summarysleep_tmp2)) {
+                          qqq[1] = nightsi[wi-1] + 1
+                          qqq[2] = nightsi[wi]
+                        } else if (wi>nrow(summarysleep_tmp2)) {
+                          qqq[1] = qqq[2] + 1
+                          qqq[2] = length(diur)
+                        }
+                      } else if(timewindowi == "WW") {
+                        if (wi==1){
+                          if (waketi > 0) {
+                            qqq[1] = waketi +1
+                          } else {
+                            qqq[1] = 1
+                          }
+                          qqq[2]=which(diff(diur) == -1)[wi] + 1
+                        } else if (wi<=nrow(summarysleep_tmp2)) {
+                          qqq[1] = which(diff(diur) == -1)[wi-1] + 1
+                          qqq[2] = which(diff(diur) == -1)[wi]
+                        } else if (wi>nrow(summarysleep_tmp2)) {
+                          qqq[1] = qqq[2] + 1
+                          qqq[2] = length(diur)
+                        }
                       }
                       if (length(which(is.na(qqq)==TRUE)) == 0) { #if it is a meaningful day then none of the values in qqq should be NA
                         fi = 1
@@ -411,46 +422,127 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
                         ds_names[fi] = "id";      fi = fi + 1
                         dsummary[di,fi] = fnames.ms3[i]
                         ds_names[fi] = "filename";      fi = fi + 1
-                        dsummary[di,fi:(fi+1)] = c(as.character(summarysleep_tmp2$weekday[wi]),as.character(summarysleep_tmp2$calendardate[wi]))
-                        ds_names[fi:(fi+1)] = c("weekday","calendardate");  fi = fi + 2
-                        dsummary[di,fi] = j
-                        ds_names[fi] = "acc_def";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$night[wi]
-                        ds_names[fi] = "night number";      fi = fi + 1                
-                        dsummary[di,fi] = summarysleep_tmp2$acc_onset[wi]
-                        ds_names[fi] = "acc_onset";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$acc_wake[wi]
-                        ds_names[fi] = "acc_wake";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$sleeplog_onset[wi]
-                        ds_names[fi] = "sleeplog_onset";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$sleeplog_wake[wi]
-                        ds_names[fi] = "sleeplog_wake";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$acc_onset_ts[wi]     
-                        ds_names[fi] = "acc_onset_ts";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$acc_wake_ts[wi]
-                        ds_names[fi] = "acc_wake_ts";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$sleeplog_onset_ts[wi]
-                        ds_names[fi] = "sleeplog_onset_ts";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$sleeplog_wake_ts[wi]
-                        ds_names[fi] = "sleeplog_wake_ts";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$daysleeper[wi]
-                        ds_names[fi] = "daysleeper";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$cleaningcode[wi]
-                        ds_names[fi] = "cleaningcode";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$sleeplog_used[wi]
-                        ds_names[fi] = "sleeplog_used";      fi = fi + 1
-                        dsummary[di,fi] = summarysleep_tmp2$acc_available[wi]
-                        ds_names[fi] = "acc_available";      fi = fi + 1
-                        # define time windows
-                        if (timewindowi == "MM") { # midnight to midnight
-                          qqq1 = nightsi[wi]+1
-                          qqq2 = nightsi[wi+1]
-                          dsummary[di,fi] = "MM"
-                        } else { #waking to waking
-                          qqq1 = which(diff(diur) == -1)[wi]+1 #waking time (select based on diurnal marking)
-                          qqq2 = which(diff(diur) == -1)[wi+1] #wakingtime next day (select based on diurnal marking)
-                          dsummary[di,fi] = "WW"
+                        if (timewindowi == "WW") {
+                          plusb = 0
+                        } else {
+                          plusb = 1
                         }
+                        if(wi>nrow(summarysleep_tmp2)+plusb) {
+                          dsummary[di,fi:(fi+1)] = c(weekdays(as.Date(summarysleep_tmp2$calendardate[wi-1], format="%e/%m/%Y")+1),
+                                                     as.character(as.Date(summarysleep_tmp2$calendardate[wi-1], format="%e/%m/%Y")+1))
+                          ds_names[fi:(fi+1)] = c("weekday","calendardate");  fi = fi + 2
+                          dsummary[di,fi] = j
+                          ds_names[fi] = "acc_def";      fi = fi + 1
+                          dsummary[di,fi] = summarysleep_tmp2$night[wi-1]+1
+                          ds_names[fi] = "night number";      fi = fi + 1
+                          dsummary[di,fi:(fi+11)] = NA  #Since this is data afte last night, we don't have sleep information here
+                          ds_names[fi:(fi+11)] = c("acc_onset","acc_wake","sleeplog_onset","sleeplog_wake",
+                                                   "acc_onset_ts","acc_wake_ts","sleeplog_onset_ts","sleeplog_wake_ts",
+                                                   "daysleeper","cleaningcode","sleeplog_used","acc_available"); fi = fi + 12
+                          
+                        } else {
+                          if(timewindowi == "MM" & wi == nrow(summarysleep_tmp2)+plusb) { # for the last day a ot of information is missing, so fill in defaults 
+                            dsummary[di,fi:(fi+1)] = c(weekdays(as.Date(summarysleep_tmp2$calendardate[wi-1], format="%e/%m/%Y")+1),
+                                                       as.character(as.Date(summarysleep_tmp2$calendardate[wi-1], format="%e/%m/%Y")+1))
+                            ds_names[fi:(fi+1)] = c("weekday","calendardate");  fi = fi + 2
+                            dsummary[di,fi] = j
+                            ds_names[fi] = "acc_def";      fi = fi + 1
+                            dsummary[di,fi] = summarysleep_tmp2$night[wi-1]+1
+                            ds_names[fi] = "night number";      fi = fi + 1
+                          } else {
+                            
+                            dsummary[di,fi:(fi+1)] = c(as.character(summarysleep_tmp2$weekday[wi]),
+                                                       as.character(as.Date(summarysleep_tmp2$calendardate[wi], format="%e/%m/%Y")))
+                            ds_names[fi:(fi+1)] = c("weekday","calendardate");  fi = fi + 2
+                            dsummary[di,fi] = j
+                            ds_names[fi] = "acc_def";      fi = fi + 1
+                            dsummary[di,fi] = summarysleep_tmp2$night[wi]
+                            ds_names[fi] = "night number";      fi = fi + 1
+                          }
+                          dsummary[di,fi] = summarysleep_tmp2$acc_onset[wi]
+                          ds_names[fi] = "acc_onset";      fi = fi + 1
+                          if (timewindowi == "WW") {
+                            dsummary[di,fi] = summarysleep_tmp2$acc_wake[wi]
+                          } else {
+                            if (wi > 1) dsummary[di,fi] = summarysleep_tmp2$acc_wake[wi-1]
+                          }
+                          ds_names[fi] = "acc_wake";      fi = fi + 1
+                          
+                          dsummary[di,fi] = summarysleep_tmp2$sleeplog_onset[wi]
+                          
+                          ds_names[fi] = "sleeplog_onset";      fi = fi + 1
+                          if (timewindowi == "WW") {
+                            dsummary[di,fi] = summarysleep_tmp2$sleeplog_wake[wi]
+                          } else {
+                            if (wi > 1) dsummary[di,fi] = summarysleep_tmp2$sleeplog_wake[wi-1]
+                          }
+                          ds_names[fi] = "sleeplog_wake";      fi = fi + 1
+                          
+                          dsummary[di,fi] = summarysleep_tmp2$acc_onset_ts[wi]     
+                          
+                          ds_names[fi] = "acc_onset_ts";      fi = fi + 1
+                          if (timewindowi == "WW") {
+                            dsummary[di,fi] = summarysleep_tmp2$acc_wake_ts[wi]
+                          } else {
+                            if (wi >1) dsummary[di,fi] = summarysleep_tmp2$acc_wake_ts[wi-1]
+                          }
+                          ds_names[fi] = "acc_wake_ts";      fi = fi + 1
+                          
+                          dsummary[di,fi] = summarysleep_tmp2$sleeplog_onset_ts[wi]
+                          
+                          ds_names[fi] = "sleeplog_onset_ts";      fi = fi + 1
+                          if (timewindowi == "WW") {
+                            dsummary[di,fi] = summarysleep_tmp2$sleeplog_wake_ts[wi]
+                          } else {
+                            if (wi > 1) dsummary[di,fi] = summarysleep_tmp2$sleeplog_wake_ts[wi-1]
+                          }
+                          ds_names[fi] = "sleeplog_wake_ts";      fi = fi + 1
+                          dsummary[di,fi] = summarysleep_tmp2$daysleeper[wi]
+                          # if timewindowi is MM then the following variables are less informative,
+                          # because they only refer to the evening and not the morning.
+                          ds_names[fi] = "daysleeper";      fi = fi + 1
+                          dsummary[di,fi] = summarysleep_tmp2$cleaningcode[wi]
+                          ds_names[fi] = "cleaningcode";      fi = fi + 1
+                          dsummary[di,fi] = summarysleep_tmp2$sleeplog_used[wi]
+                          ds_names[fi] = "sleeplog_used";      fi = fi + 1
+                          dsummary[di,fi] = summarysleep_tmp2$acc_available[wi]
+                          ds_names[fi] = "acc_available";      fi = fi + 1
+                        }
+                        # 
+                        # define time windows
+                        # qqq definitions changed so we get acc_onset and acc_wake regarding to the same day of measurement in the same row.
+                        # Also, it allows for the analysis of the first day for those studies in which the accelerometer is started during the morning and the first day is of interest.
+                        if (timewindowi == "MM") {
+                          if (wi==1) {
+                            # if (waketi > 0) {
+                            #   qqq1 = waketi + 1
+                            # } else {
+                            qqq1 = 1
+                            # }
+                            qqq2 = nightsi[wi]
+                          } else if (wi<=nrow(summarysleep_tmp2)) {
+                            qqq1 = nightsi[wi-1] + 1
+                            qqq2 = nightsi[wi]
+                          } else if (wi>nrow(summarysleep_tmp2)) {
+                            qqq1 = qqq2 + 1
+                            qqq2 = length(diur)
+                          }
+                          dsummary[di, fi] = "MM"
+                        } else if (timewindowi == "WW") {
+                          if (wi==1){
+                            if (waketi > 0) qqq1 = waketi + 1
+                            else {qqq1 = 1}
+                            qqq2 = which(diff(diur) == -1)[wi] + 1
+                          } else if (wi<=nrow(summarysleep_tmp2)) {
+                            qqq1 = which(diff(diur) == -1)[wi-1] + 1
+                            qqq2 = which(diff(diur) == -1)[wi]
+                          } else if (wi>nrow(summarysleep_tmp2)) {
+                            qqq1 = qqq2 + 1
+                            qqq2 = length(diur)
+                          }
+                          dsummary[di, fi] = "WW"
+                        }
+                        
                         ds_names[fi] = "window";      fi = fi + 1    
                         # keep track of threshold value
                         dsummary[di,fi] = TRLi
@@ -473,9 +565,10 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
                         ds_names[fi] = "nonwear_hours";      fi = fi + 1
                         #===============================================
                         # TIME SPENT IN WINDOWS (window is either midnight-midnight or waking up-waking up)
+                        test_remember = c(di,fi)
                         for (levelsc in 0:(length(Lnames)-1)) {
                           dsummary[di,fi] = (length(which(LEVELS[qqq1:qqq2] == levelsc)) * ws3) / 60
-                          ds_names[fi] = paste("dur_",Lnames[levelsc+1],"_min",sep="");      fi = fi + 1
+                          ds_names[fi] = paste0("dur_",Lnames[levelsc+1],"_min");      fi = fi + 1
                         }
                         for (g in 1:5) {
                           dsummary[di,(fi+(g-1))] = (length(which(OLEVELS[qqq1:qqq2] == g )) * ws3) / 60
@@ -492,7 +585,6 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
                         dsummary[di,fi] = (length(c(qqq1:qqq2)) * ws3) / 60
                         ds_names[fi] = "dur_nightandday_min";      fi = fi + 1
                         
-                        
                         #============================================
                         # Number of long wake periods (defined as > 5 minutes) during the night
                         Nawake = length(which(abs(diff(which(LEVELS[qqq1:qqq2] == 0))) > (300 / ws3))) - 2
@@ -503,19 +595,19 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
                         # percentage of available data
                         zt_hrs_nonwear = (length(which(diur[qqq1:qqq2] == 0 & nonwear[qqq1:qqq2] == 1)) * ws3) / 3600 #day
                         zt_hrs_total = (length(which(diur[qqq1:qqq2] == 0)) * ws3) / 3600 #day
-                        dsummary[di,fi] = round( (zt_hrs_nonwear/zt_hrs_total)  * 10000) / 100
+                        dsummary[di,fi] = (zt_hrs_nonwear/zt_hrs_total)  * 10000 / 100
                         ds_names[fi] = "nonwear_perc_day";      fi = fi + 1
                         zt_hrs_nonwear = (length(which(diur[qqq1:qqq2] == 1 & nonwear[qqq1:qqq2] == 1)) * ws3) / 3600 #night
                         zt_hrs_total = (length(which(diur[qqq1:qqq2] == 1)) * ws3) / 3600 #night
-                        dsummary[di,fi] =  round((zt_hrs_nonwear/zt_hrs_total)  * 10000) / 100
+                        dsummary[di,fi] =  (zt_hrs_nonwear/zt_hrs_total)  * 10000 / 100
                         ds_names[fi] = "nonwear_perc_night";      fi = fi + 1
                         zt_hrs_nonwear = (length(which(nonwear[qqq1:qqq2] == 1)) * ws3) / 3600
                         zt_hrs_total = (length(diur[qqq1:qqq2]) * ws3) / 3600 #night and day
-                        dsummary[di,fi] =  round((zt_hrs_nonwear/zt_hrs_total)  * 10000) / 100
+                        dsummary[di,fi] =  (zt_hrs_nonwear/zt_hrs_total)  * 10000 / 100
                         ds_names[fi] = "nonwear_perc_nightandday";      fi = fi + 1
                         #=============================
                         # sleep efficiency
-                        dsummary[di,fi] = length(which(detection[qqq1:qqq2] == 1 & diur[qqq1:qqq2] == 1)) / length(which(diur[qqq1:qqq2] == 1))
+                        dsummary[di,fi] = length(which(sibdetection[qqq1:qqq2] == 1 & diur[qqq1:qqq2] == 1)) / length(which(diur[qqq1:qqq2] == 1))
                         ds_names[fi] = "sleep_efficiency";      fi = fi + 1
                         #===============================================
                         # AVERAGE ACC PER WINDOW
@@ -679,6 +771,7 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
                           ds_names[fi] = "foldername"; fi = fi + 1 
                         }
                         di = di + 1
+                        
                       }
                     }
                   }
@@ -687,8 +780,23 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
             }
           }
         }
+        #remove NA values
+        for (kik in 1:ncol(dsummary)) {
+          naval = which(is.na(dsummary[,kik])==TRUE)
+          if(length(naval) > 0) dsummary[naval,kik] = ""
+        }
         output = data.frame(dsummary,stringsAsFactors=FALSE)
         names(output) = ds_names
+        
+        # This is not a good solution anymore: If excludefirstlast == TRUE then part4 does not generate sleep estimates for the first and last night,
+        # therefore, part5 will also mis waking up time for the second and the beforelast day.
+        # So, I think if we want to facilitate that the first and last day are excluded in part5 then this will have to be handled
+        # with a different input argument
+        if (excludefirstlast.part5 == TRUE) { #undesirable because it will slowly remove alchanged to TRUE on 20 May 2015
+          output = output[-c(which(output$night_number == min(output$night_number)),
+                             which(output$night_number == max(output$night_number))),] #Moved here, first, it analyzes the whole measurement, then it selects the days to show
+        }
+        
         # correct definition of sleep log availability for window = WW, because now it
         # also relies on sleep log from previous night
         whoareWW = which(output$window == "WW") # look up WW
@@ -722,3 +830,4 @@ g.part5 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy=1,maxdur=7
     }
   }
 }
+
