@@ -1,4 +1,6 @@
 library(GGIR)
+context("create_test_sleeplog_csv")
+options(encoding = "UTF-8")
 test_that("create_test_sleeplog_csv produces a file", {
   create_test_sleeplog_csv()
   fn = "testsleeplogfile.csv"
