@@ -1,4 +1,6 @@
 library(GGIR)
+context("g.impute")
+options(encoding = "UTF-8")
 test_that("g.impute returns a non-empty dataframe", {
   data(data.getmeta)
   data(data.inspectfile)
