@@ -1,4 +1,6 @@
 library(GGIR)
+context("getfolderstructure")
+options(encoding = "UTF-8")
 test_that("getfolderstructure", {
   dn = "A" # name of the datadir folder
   if (file.exists(dn))  unlink(dn,recursive=TRUE)
@@ -16,7 +18,4 @@ test_that("getfolderstructure", {
   expect_that(  folderstructure$foldername[1],equals("B"))
   expect_that(  folderstructure$foldername[2],equals("C"))
   if (file.exists(dn))  unlink(dn,recursive=TRUE)
-})
-  
-
-
+})
\ No newline at end of file
